summaryrefslogtreecommitdiff
path: root/src/pkg/testing/iotest/logger.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/pkg/testing/iotest/logger.go')
-rw-r--r--src/pkg/testing/iotest/logger.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/pkg/testing/iotest/logger.go b/src/pkg/testing/iotest/logger.go
index 5e511bdf6..c3bf5df3c 100644
--- a/src/pkg/testing/iotest/logger.go
+++ b/src/pkg/testing/iotest/logger.go
@@ -18,15 +18,15 @@ type writeLogger struct {
func (l *writeLogger) Write(p []byte) (n int, err os.Error) {
n, err = l.w.Write(p)
if err != nil {
- log.Stdoutf("%s %x: %v", l.prefix, p[0:n], err)
+ log.Printf("%s %x: %v", l.prefix, p[0:n], err)
} else {
- log.Stdoutf("%s %x", l.prefix, p[0:n])
+ log.Printf("%s %x", l.prefix, p[0:n])
}
return
}
// NewWriteLogger returns a writer that behaves like w except
// that it logs (using log.Stdout) each write to standard output,
// printing the prefix and the hexadecimal data written.
func NewWriteLogger(prefix string, w io.Writer) io.Writer {
return &writeLogger{prefix, w}
@@ -40,15 +40,15 @@ type readLogger struct {
func (l *readLogger) Read(p []byte) (n int, err os.Error) {
n, err = l.r.Read(p)
if err != nil {
- log.Stdoutf("%s %x: %v", l.prefix, p[0:n], err)
+ log.Printf("%s %x: %v", l.prefix, p[0:n], err)
} else {
- log.Stdoutf("%s %x", l.prefix, p[0:n])
+ log.Printf("%s %x", l.prefix, p[0:n])
}
return
}
// NewReadLogger returns a reader that behaves like r except
-// that it logs (using log.Stdout) each read to standard output,
+// that it logs (using log.Print) each read to standard error,
// printing the prefix and the hexadecimal data written.
func NewReadLogger(prefix string, r io.Reader) io.Reader {
return &readLogger{prefix, r}
@@ -18,15 +18,15 @@ type writeLogger struct {
}
// NewWriteLogger returns a writer that behaves like w except
-// that it logs (using log.Stdout) each write to standard output,
+// that it logs (using log.Printf) each write to standard error,
// printing the prefix and the hexadecimal data written.
func NewWriteLogger(prefix string, w io.Writer) io.Writer {